@@ -10,15 +10,15 @@
 #define KCM_H
 
 #include "core/firewallclient.h"
-#include <KQuickAddons/ConfigModule>
+#include <KQuickConfigModule>
 
-class KCMFirewall : public KQuickAddons::ConfigModule
+class KCMFirewall : public KQuickConfigModule
 {
     Q_OBJECT
     Q_PROPERTY(FirewallClient *client READ client CONSTANT)
 
 public:
-    explicit KCMFirewall(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    explicit KCMFirewall(QObject *parent, const KPluginMetaData &metaData);
 
     ~KCMFirewall();
     void save() override;
